.. _mathematics:

**********************************************
Mathematics (`plasmapy.formulary.mathematics`)
**********************************************

.. currentmodule:: plasmapy.formulary.mathematics

.. automodapi:: plasmapy.formulary.mathematics
